//
// F2App.cpp : The main application class.
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#include "stdhdr.h"

// Application declaration
#include "F2App.h"

// Application window
#include "F2Window.h"

// For resource IDs
#include "Res\Resource.h"

// For redrawing the window contents
#include "vgui\RedrawGC.h"

#include "vgui\ErrorReporter.h"
#include "vgui\Alert.h"
#include "vgui\Question.h"
#include "vgui\Errors.h"

#include "vos\Preferences.h"

//
// Enable vOS memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	
	/**************************************************************************

	>	Application *CreateApplication()

		Purpose:	Create the instance of the application object we want to
					use for this program.

					This is called by the vGUI library on startup, and is how
					we control what type of application is created.

	**************************************************************************/

	Application *CreateApplication()
	{
		return new F2App;
 	}
};

//
// Message map for the application - minimal functionality.
//
// Here we simply link the IDM_EXIT menu command to the vgui 
// Application::Exit() function, so that when the user chooses
// Exit from the menu, the program will exit.
//
BEGIN_VGUI_MESSAGE_MAP(F2App, Application)
	ON_VGUI_COMMAND(IDM_EXIT, Exit)
END_VGUI_MESSAGE_MAP()



/**************************************************************************

>	F2App::F2App()

	Author:		vGUI AppWizard

	Purpose:	Constructor - sets up the main application object.

				In this function, we tell the vGUI library what the
				application is called, which menu resource to use,
				which hotkey/accelerator resource to use, and initialise
				any optional vGUI sub-systems that we will use.

**************************************************************************/

F2App::F2App()
{
	// Set the app title.
	m_resAppTitle = vgui::StringResourceID(IDS_APP_TITLE);

	// Set the menu resource ID
	m_resMenu = vgui::MenuResourceID(IDM_F2);

	// Set the main application icon resource ID
	m_resIcon = vgui::IconResourceID(IDI_F2);
	m_resSmallIcon = vgui::IconResourceID(IDI_F2_SMALL);

	// Set keyboard accelerators
	m_resAccelerators = vgui::AcceleratorResourceID(IDC_ACCEL_F2);

	// Set up Alert system
	vgui::Alert::Initialise(IDD_VGUI_ALERT, 
							IDC_ALERT_TEXT, 
							IDOK,
							IDC_VGUI_ALERT_DONTTELLMEAGAIN);

	// Set up Question system
	vgui::Question::Initialise(IDD_VGUI_QUESTION, 
							   IDC_QUESTION_TEXT, 
							   IDC_VGUI_QUESTION_DEFAULT,
							   IDC_VGUI_QUESTION_OTHER,
							   IDC_VGUI_QUESTION_DONTASKAGAIN);

	// Set up error handlers so that we get a dialog instead of the vOS
	// default of trace output and a debugger interrupt.
	SetupErrorReporter();

	// Set up preferences system
	vos::Preferences::Init("Guys With Towels", "F2");
}



/**************************************************************************

>	void F2App::SetupErrorReporter()

	Author:		vGUI AppWizard

	Purpose:	Set up the vOS error system to use the standard vGUI
				error reporting dialog system.  If you want to use your
				own system, simply derive your own class from 
				vos::ErrorReporter and tell vOS to use that instead.

**************************************************************************/

void F2App::SetupErrorReporter()
{
	vgui::ErrorReporterInfo Info;

	// Dialog for debug builds...
	Info.m_ErrorDialog_Debug = IDD_VGUI_REPORTERROR_DEBUG;
	Info.m_ContinueButton = IDC_VGUI_CONTINUE;
	Info.m_DebugButton = IDC_VGUI_DEBUG;
	Info.m_AbortButton = IDC_VGUI_ABORT;
	Info.m_ErrorText = IDC_VGUI_ERRORTEXT;
	Info.m_ErrorDetailsText = IDC_VGUI_ERRORDETAILS;
	Info.m_MoreInfoButton = IDC_VGUI_MOREINFO;
	Info.m_PrevErrorButton = IDC_VGUI_PREVERROR;

	// Dialog for release builds...
	Info.m_ErrorDialog_Release = IDD_VGUI_REPORTERROR_RELEASE;


	// Use this information to create a vGUI based error reporter.
	vgui::vGuiErrorReporter* pMyErrorReporter = new vgui::vGuiErrorReporter(Info);

	// And install it.
	vos::TheErrorManager().SetErrorReporter(pMyErrorReporter);
}


/**************************************************************************

>	vgui::Dialog* F2App::CreateTheDialog()

	Author:		vGUI AppWizard
	Returns:	The main Dialog object for the application.

	Purpose:	Create the main dialog window for the application

**************************************************************************/

vgui::Dialog* F2App::CreateTheDialog()
{
	// Create our application dialog...
	return new F2Window(this);
}


