//
// F2Window.h - the class declaration for the main window object.
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//


#ifndef inc_F2Window_h
#define inc_F2Window_h

#include "vgui\Application.h"

#include "vgui\Dialog.h"
#include "vgui\EditBox.h"
#include "vgui\CheckBox.h"
#include "vgui\RadioButton.h"
#include "vgui\ProgressBar.h"
#include "vgui\ListBox.h"
#include "vgui\JobController.h"

#include "vos\MonotonicTime.h"

#include "FilenameList.h"
#include "RenameUndoManager.h"

#define kPreviewDelay (2000)

typedef enum
{
	F2State_RenameAllowed,
	F2State_ErrorsOutstanding
}
F2State;

/**************************************************************************

>	class F2Window : public vgui::Dialog

	Author:		vGUI AppWizard

	Purpose:	Implement the main window object for this application.

**************************************************************************/

class F2Window : public vgui::Dialog,
				 public vgui::IdleHandler,
				 public vgui::JobController
{
	public:
		DECLARE_VGUI_MESSAGE_MAP();

		void OnInitDialog();

	public:
		F2Window(vgui::Application *pApp);

	private:
		// Control of showing filenames etc
		void ForceFolderScan();
		void ForceFilter(uint msDelay = kPreviewDelay);
		void ForcePreview(uint msDelay = kPreviewDelay);
		void ForceValidate(uint msDelay = kPreviewDelay);

		void ScheduleBackgroundProcess(int msDelay = kPreviewDelay);
		void StartBackgroundProcess();
		void CancelBackgroundProcessing();

	private:
		void FillFileList();

		bool OnFileSelectionChange();
		bool OnPreview();
		bool OnRename();
		bool OnFilterFilesClicked();
		bool OnFilterCommit();
		bool OnRenameCommit();
		bool OnRefresh();
		bool OnBrowse();
		bool OnUndo();
		bool OnClearErrors();
		bool OnOptions();

		bool OnResize(int NewWidth, int NewHeight);

		bool OnSortChange();
		bool OnSortNow();
		
		bool MakeNewName(int iFileItem, vos::String* pNewName);

		void ResizeColumns();
		void ResizeFilenameColumns();

		bool OnKeyDown(vgui::TKeyCode Key, int Modifiers);
		bool OnTimer(vgui::TimerID ID);

		void EnterErrorProgramState();
		void RestoreNormalState();

		void SetFolderOptions();
		void SetFilterOptions();
		void SetRenameOptions();

		// Control of scanning
		bool OnFolderNameChanged();
		bool OnFilterOptionChanged();
		bool OnRenameSchemeChanged();

		void KillTimer();

		//
		// IdleHandler interface
		//
		virtual bool OnIdle(uint iIdleEvent);

		//
		// JobController interface
		//

		// Change the displayed description of the job
		virtual void SetJobDescription(const vos::String& Description);

		// Update any progress display to use the new percentage value
		virtual void UpdateJobProgressDisplay(uint PercentComplete);

		// Hide progress display - for jobs that have indeterminate length
		virtual void HideProgressDisplay();

		// Find out if the user has cancelled the operation yet.
		virtual bool IsJobCancelled() const;


		// Extra function to show progress display
		void ShowProgressDisplay();

		void RefreshFilenameStatus();
		void ForceFileListSort();
		
		//
		// Sorting
		//
		static int ListSortFunction(const vgui::ListControl* pListControl, 
									vgui::UserData TheUserData,
								    int iItem1, int iItem2, 
								    int iColumn);

	private:
		// Program state
		F2State m_State;

		// Dialog controls
		vgui::EditBox m_FolderName;
		vgui::CheckBox m_UseFilter;
		vgui::RadioButton m_UseNormalFilter;
		vgui::RadioButton m_UseRegExpFilter;
		vgui::CheckBox m_IgnoreCase;

		vgui::EditBox m_FileFilter;
		vgui::CheckBox m_SortOnStatus;
		vgui::CheckBox m_bAutoSizeColumns;
		
		vgui::Window m_ErrorMessage;
		
		vgui::EditBox m_Pattern;
		vgui::EditBox m_NewName;

		vgui::CheckBox m_UseMP3Tags;

		vgui::ListBox m_FileList;

		// Mechanisms for progress display
		vgui::ProgressBar m_ProgressBar;
		vgui::Window m_ProgressLabel;
		bool m_bProgressDisplayVisible;
		bool m_bFullProgressDisplayVisible;
		vos::String m_JobDescription;
		int m_ProgressWidth;

		// The list of files to rename
		FilenameList m_FilenameList;

		// The undo manager for rename ops
		RenameUndoManager m_UndoManager;

		// Timer event used to trigger real-time preview
		vgui::TimerID m_TimerID;

		// Whether or not we're goind bg processing
		bool m_bDoingBackgroundProcessing;

		// Time we start the scan/filter/preview job
		uint32 m_TimeJobStarted;

		// Sorting control
		bool m_bSortByStatusFirst;
};

#endif // !inc_F2Window_h
