//
// FileRenameWorker.h
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#ifndef inc_FileRenameWorker_h
#define inc_FileRenameWorker_h

#include "vgui\JobWorker.h"
#include "vgui\ListBox.h"

#include "FileRenamer.h"

class FilenameList;
class IFileRenamerMonitor;

//
// Used to control how we deal with read-only files.
//
typedef enum
{
	ReadOnlyAction_Ask,
	ReadOnlyAction_Ignore,
	ReadOnlyAction_Rename
}
TReadOnlyAction;

/**************************************************************************

>	class FileRenameWorker : public vgui::JobWorker

	Author:		Tim Browse
	Date:		29/4/2002

	Purpose:	Fill a list view control with previews of new filenames.

**************************************************************************/

class FileRenameWorker : public vgui::JobWorker
{
	public:
		// Constructor
		FileRenameWorker(FilenameList* pFilenameList,
						 IFileRenamerMonitor* pMonitor = NULL);

		// Do a block of work, and let the ProgressDialog know how much of
		// the work has been completed so far, and whether the work has
		// been finished or not.
		virtual vgui::TJobStatus DoWork(vgui::JobController* pJobController,
										int* pPercentComplete);

		// The user has clicked the "Cancel" button, so the worker object
		// should perform any shutdown necessary before returning.  The
		// object will not be called by the ProgressDialog at all after
		// this function has been called.
		virtual void OnCancel(vgui::JobController* pJobController);

		// Find out if the rename operation was successful
		bool WasRenameSuccessful();

	private:
		bool AskUserAboutReadOnlyFile(const vos::String& Filename);

	private:
		// Info needed to direct work
		FilenameList* m_pFilenameList;

		// Status of work
		uint m_cFiles;
		uint m_iCurrentFile;

		// Object that actually renames the files for us
		FileRenamer m_Renamer;

		// How do we handle read-only files?
		TReadOnlyAction m_ReadOnlyAction;
};

#endif // !inc_FileRenameWorker_h
