//
// FileRenamer.h
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#ifndef inc_FileRenamer_h
#define inc_FileRenamer_h

#include "vos\FileSpec.h"

#include "FilenameTransformer.h"

class IFileRenamerMonitor;

/**************************************************************************

>	class FileRenamer : public vos::CreateFolderHandler

	Author:		Tim Browse
	Date:		29/4/2002

	Purpose:	An object that can be used to rename a set of files, based
				on a FileTransformSpec, that is used to control how the
				files are renamed.

				Simple create an object, call SetTransformSpec() to tell
				it how to rename files, and then repeatedly call
				RenameFile() to use it to rename files.

				Any errors that occur during a rename operation are
				returned by RenameFile().

**************************************************************************/

class FileRenamer : public vos::CreateFolderHandler
{
	public:
		// Constructor
		FileRenamer();

		// Call this first...
		void SetFolder(const vos::FileSpec& fsFolder);
	
		// ...then call these as any times as you need
		vos::Error RenameFile(uint iFileIndex,
							  const vos::FileSpec& fsFileToRename,
							  const vos::FileSpec& fsNewFilename);

		// Use this if you want to know what happens in detail
		void SetMonitor(IFileRenamerMonitor* pMonitor);

	private:
		void NotifyFolderCreated(const vos::FileSpec& NewFolderName);

		void CleanUpFolders();

	private:
		// Location of the files we are renaming
		vos::FileSpec m_fsFolder;
		IFileRenamerMonitor* m_pMonitor;

		// List of folders created when renaming a file
		std::vector<vos::FileSpec> m_NewFolders;
};

#endif // !inc_FileRenamer_h
