//
// FilenameTransformer.h
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#ifndef inc_FilenameTransformer_h
#define inc_FilenameTransformer_h

#include "vos\Errors.h"

#include "FilenameTransformSpec.h"

//
// Indicates how a filename transform went
//
typedef enum
{
	TransformResult_OK,
	TransformResult_BadMetaData,
	TransformResult_PatternMatchFail
}
TransformResult;

/**************************************************************************

>	class FilenameTransformer

	Author:		Tim Browse
	Date:		29/4/2002

	Purpose:	Generic 'renaming engine' for renaming files according
				to the FilenameTransformSpec passed to the constructor.

				You create an object, giving the transform spec, then
				repeatedly pass it the names of the files you want to
				rename.

**************************************************************************/

class FilenameTransformer
{
	public:
		// Constructor
		FilenameTransformer() {}
		FilenameTransformer(const FilenameTransformSpec& Spec);

		// Set up transform spec for this object
		void SetSpec(const FilenameTransformSpec& Spec);

		// Construct the new name for the file
		TransformResult TransformFilename(const vos::String& Filename,
										  vos::String* pNewFilename);

		// Get the folder that holds the files we are transforming
		vos::FileSpec GetFolder();

	private:
		// How to transform the filenames
		FilenameTransformSpec m_Spec;
		
		// Whether or not the transform spec requires us to scan
		// for mp3 tags
		bool m_bUseMP3Tags;
};

#endif // !inc_FilenameTransformer_h
