//
// FilterFilesWorker.cpp
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "FilterFilesWorker.h"

#include "FilenameList.h"

/**************************************************************************

>	FilterFilesWorker::FilterFilesWorker(FilenameList* pFilenameList)

	Author:		Tim Browse
	Date:		30/4/2002
	Inputs:		fsFolderToScan - the folder to scan for files
				pFileSpecs - the filespec container to fill with details
							 of the files that are scanned.

	Purpose:	Constructor - specify which folder to scan for files.

**************************************************************************/

FilterFilesWorker::FilterFilesWorker(FilenameList* pFilenameList) : m_pFilenameList(pFilenameList),
																	m_bFinished(false),
																	m_cFiles(0),
																	m_iCurrentFile(0)
{
	// Clear the filter array before we start
	m_pFilenameList->m_FilteredFilenames.clear();

	// Find out how many files we have
	m_cFiles = m_pFilenameList->m_Filenames.size();
}

/**************************************************************************

>	vgui::TJobStatus FilterFilesWorker::DoWork(vgui::JobController* pJobController,
														  int* pPercentComplete)

	Author:		Tim Browse
	Date:		30/4/2002
	Outputs:	pPercentComplete - the current completion status.
	Returns:	JobWorker_Finished - work has complete
				JobWorker_NotFinished - work is not finished, and the
											 worker object is expecting this
											 function to be called again.

	Purpose:	Scan a batch of files.

**************************************************************************/

vgui::TJobStatus FilterFilesWorker::DoWork(vgui::JobController* pJobController,
													  int* pPercentComplete)
{
	m_bFinished = false;

	int cFilesToFilter = 50;

	while ((cFilesToFilter > 0) && (m_iCurrentFile < m_cFiles))
	{
		// Does this file match?
		if (m_pFilenameList->FileMatchesFilter(m_pFilenameList->m_Filenames[m_iCurrentFile]))
		{
			// Yes, so add it to the list of filtered files
			m_pFilenameList->m_FilteredFilenames.push_back(m_iCurrentFile);
		}

		// Try next file
		m_iCurrentFile++;
		cFilesToFilter--;
	}

	// Tell caller how far we've got
	if (m_cFiles > 0)
		*pPercentComplete = (100 * m_iCurrentFile) / m_cFiles;
	else
		*pPercentComplete = 100;

	// Tell caller if we're done yet
	if (m_iCurrentFile == m_cFiles)
	{
		m_bFinished = true;
		return vgui::Job_Finished;
	}
	else
	{
		return vgui::Job_NotFinished;
	}
}

/**************************************************************************

>	void FilterFilesWorker::OnCancel(vgui::JobController* pJobController)

	Author:		Tim Browse
	Date:		30/4/2002
	Inputs:		pProgressDialog - the progress dialog being used.

	Purpose:	Handle the user cancelling the scan request

**************************************************************************/

void FilterFilesWorker::OnCancel(vgui::JobController* pJobController)
{
	// Clear out the filter list
	m_pFilenameList->m_FilteredFilenames.clear();
}


