//
// IFileRenamerMonitor.h
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#ifndef inc_IFileRenamerMonitor_h
#define inc_IFileRenamerMonitor_h

#include "vos\FileSpec.h"

/**************************************************************************

>	class IFileRenamerMonitor

	Author:		Tim Browse
	Date:		29/4/2002

	Purpose:	Interface definition for monitoring what a FileRenamer
				object is doing, such as the details of when a file is
				renamed or a folder is created/deleted.

				Primarily exists to allow undo functionality to be
				implemented.

				NB. A folder would be deleted when it was created to hold
					a file, but the rename operation itself failed for some
					reason. Therefore we delete any folders we created in
					order to hold the new file.

**************************************************************************/

class IFileRenamerMonitor
{
	public:
		virtual void NotifyFileRenamed(uint iFileIndex,
									   const vos::FileSpec& fsOldName,
									   const vos::FileSpec& fsNewName) = 0;

		virtual void NotifyFolderCreated(const vos::FileSpec& fsNewFolder) = 0;
		virtual void NotifyFolderDeleted(const vos::FileSpec& fsDeletedFolder) = 0;
};

#endif // !inc_IFileRenamerMonitor_h

