//
// MP3TagReader.cpp
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "MP3TagReader.h"

/**************************************************************************

>	MP3TagReader::MP3TagReader(const vos::FileSpec fsMP3File)

	Author:		Tim Browse
	Date:		28/4/2002
	Inputs:		fsMP3File - name of MP3 file to read tags from.

	Purpose:	Constructor - link the tag object to a file.

**************************************************************************/

MP3TagReader::MP3TagReader(const vos::FileSpec fsMP3File) : m_bGoodTags(true)
{
	m_Tag.Link(fsMP3File.GetString().c_str());
}

/**************************************************************************

>	bool MP3TagReader::GetInfo(vos::String* pArtist, 
							   vos::String* pAlbum, 
							   vos::String* pTrackName, 
							   uint* pTrackNumber)


	Author:		Tim Browse
	Date:		28/4/2002
	Outputs:	pArtist - the artist name
				pAlbum - the album name
				pTrackName - the track name
				pTrackNumber - track number
	Returns:	true => All tags were read ok.
				false => otherwise

	Purpose:	Get basic track info from MP3 ID3 tags.

**************************************************************************/

bool MP3TagReader::GetInfo(vos::String* pArtist, 
						   vos::String* pAlbum, 
						   vos::String* pTrackName, 
						   vos::String* pTrackNumber)
{
	m_bGoodTags = true;
	ReadTextField(ID3FID_LEADARTIST, pArtist);
	ReadTextField(ID3FID_ALBUM, pAlbum);
	ReadTextField(ID3FID_TITLE, pTrackName);
	ReadTextField(ID3FID_TRACKNUM, pTrackNumber);
	return m_bGoodTags;
}

bool MP3TagReader::ReadTextField(ID3_FrameID Frame,
								 vos::String* pText)
{
	ID3_Frame* pFrame = m_Tag.Find(Frame);
	if (pFrame != NULL)
	{
		ID3_Field* pField = pFrame->GetField(ID3FN_TEXT);
		if (pField != NULL)
		{
			pText->assign(pField->GetRawText());
			return true;
		}
	}

	// Error occured
	pText->assign("BAD_MP3_TAG");
	m_bGoodTags = false;
	return false;
}

bool MP3TagReader::ReadIntegerField(ID3_FrameID Frame,
								    uint* pInteger)
{
	ID3_Frame* pFrame = m_Tag.Find(Frame);
	if (pFrame != NULL)
	{
		ID3_Field* pField = pFrame->GetField(ID3FN_DATA);
		if (pField != NULL)
		{
			*pInteger = pField->Get();
			return true;
		}
	}

	// Error occured
	return false;
}
