//
// RenameUndoManager.h
//

//
// This software is protected by the GNU General Public License,
// also known as the GPL.
//
// See the file COPYING.txt for details.
//

#ifndef inc_RenameUndoManager_h
#define inc_RenameUndoManager_h

#include "IFileRenamerMonitor.h"

#include "vgui\JobWorker.h"

#include "FileSpecs.h"

class FilenameList;

/**************************************************************************

>	class RenameUndoManager : public IFileRenamerMonitor,
							  public vgui::JobWorker


	Author:		Tim Browse
	Date:		3/5/2002

	Purpose:	Manage the undo records for renaming operations, and perform
				the undo actions when requested.

**************************************************************************/

class RenameUndoManager : public IFileRenamerMonitor,
						  public vgui::JobWorker
{
	public:
		RenameUndoManager();

		void LinkToFilenameList(FilenameList* pFilenameList);

		void ClearHistory();

		bool PossibleToUndo();

		void PrepareToUndo();
		
	public:
		//
		// IFileRenamerMonitor interface
		//
		virtual void NotifyFileRenamed(uint iFileIndex,
									   const vos::FileSpec& fsOldName,
									   const vos::FileSpec& fsNewName);

		virtual void NotifyFolderCreated(const vos::FileSpec& fsNewFolder);
		virtual void NotifyFolderDeleted(const vos::FileSpec& fsDeletedFolder);

		//
		// JobWorker interface - DoWork will attempt to undo any actions
		// registered with this manager.
		//
		virtual vgui::TJobStatus DoWork(vgui::JobController* pJobController,
												   int* pPercentComplete);

	private:
		// Details of the files that were renamed, and what they were
		// renamed to.
		FileSpecs m_OriginalFilenames;
		FileSpecs m_NewFilenames;

		// Indices of these filenames
		std::vector<uint> m_Indices;

		// Details of any folders that were created during rename operation.
		FileSpecs m_FoldersCreated;

		// State of undo operation
		uint m_cFilesToRename;
		uint m_cFoldersToDelete;

		uint m_iCurrentFile;
		int m_iCurrentFolder;

		// FilenameList we refer to during undo (to update filename status)
		FilenameList* m_pFilenameList;
};

#endif // !inc_RenameUndoManager_h
